import { Body, Controller, Get, Post, Req, UseGuards } from '@nestjs/common';
import { LinksService } from './links.service';
import { CreateLinkDTO } from './dto/create-link.dto';
import JwtAuthGuard from 'src/auth/guards/jwt-auth.guard';
import { RequestWithUser } from 'src/auth/interfaces/request-with-user.interface';

@Controller('/links')
export class LinksController {
  constructor(private readonly linksService: LinksService) {}

  @Post('/')
  @UseGuards(JwtAuthGuard)
  async createLink(
    @Body() body: CreateLinkDTO,
    @Req() request: RequestWithUser,
  ) {
    const link = await this.linksService.createLink({
      ...body,
      userId: request.user.id,
    });

    return { link };
  }

  @Get('/')
  @UseGuards(JwtAuthGuard)
  async getLinks(@Req() request: RequestWithUser) {
    const links = await this.linksService.getLinksByUser(request.user.id);

    return { links };
  }
}
