import { Injectable } from '@nestjs/common';
import { Link } from './entities/links.entity';
import { InjectRepository } from '@nestjs/typeorm';
import { MoreThanOrEqual, Repository, IsNull } from 'typeorm';

@Injectable()
export class LinksService {
  constructor(
    @InjectRepository(Link)
    private linksRepository: Repository<Link>,
  ) {}

  async createLink({ url, userId }: { url: string; userId: number }) {
    const link = this.linksRepository.create({ url, user: { id: userId } });
    return this.linksRepository.save(link);
  }

  async getLinksByUser(userId: number) {
    return this.linksRepository.findBy({ user: { id: userId } });
  }

  async getLinksByDate(minDate: Date) {
    return this.linksRepository.find({
      where: [
        { lastCheckDate: IsNull() },
        { lastCheckDate: MoreThanOrEqual(minDate) },
      ],
    });
  }
}
