import { Module } from '@nestjs/common';
import { TasksService } from './tasks.service';
import { HttpModule } from '@nestjs/axios';
import { LinksModule } from 'src/links/links.module';
import { ClientsModule, Transport } from '@nestjs/microservices';
import { ConfigModule, ConfigService } from '@nestjs/config';

@Module({
  imports: [
    ClientsModule.registerAsync([
      {
        name: 'PARSER',
        imports: [ConfigModule],
        inject: [ConfigService],
        useFactory: async (configService: ConfigService) => {
          const brokerUrl = `${configService.get(
            'KAFKA_BROKER_HOST',
          )}:${configService.get('KAFKA_BROKER_PORT')}`;
          console.log('brokerUrl: ', brokerUrl);

          return {
            transport: Transport.KAFKA,
            options: {
              client: {
                clientId: 'parsing',
                brokers: [brokerUrl],
              },
              consumer: {
                groupId: 'parsing-consumer',
              },
            },
          };
        },
      },
    ]),
    HttpModule,
    LinksModule,
  ],
  providers: [TasksService],
})
export class TasksModule {}
