import { HttpService } from '@nestjs/axios';
import { Inject, Injectable, Logger } from '@nestjs/common';
import { ClientKafka } from '@nestjs/microservices';
import { Cron, CronExpression } from '@nestjs/schedule';
import { firstValueFrom } from 'rxjs';
import { LinksService } from 'src/links/links.service';

// * * * * * *
// | | | | | |
// | | | | | day of week
// | | | | months
// | | | day of month
// | | hours
// | minutes
// seconds (optional)

@Injectable()
export class TasksService {
  private readonly logger = new Logger(TasksService.name);

  constructor(
    private readonly httpService: HttpService,
    private readonly linksService: LinksService,
    @Inject('PARSER') private readonly parserClient: ClientKafka,
  ) {}

  private async request(link: string) {
    try {
      const response = await firstValueFrom(
        this.httpService.get(`http://localhost:3000/parse?link=${link}`),
      );
      return response.data;
    } catch (e) {
      return 'Error!';
    }
  }

  @Cron('*/20 * * * * *', {
    name: 'sendParse',
    timeZone: 'Europe/Moscow',
    // disabled: true
  })
  async sendParse() {
    this.logger.log('TASK RUN');
    const links = await this.linksService.getLinksByDate(new Date());
    this.logger.log('LINKS', links);
    this.parserClient.emit(
      'link_to_parse',
      JSON.stringify(links.map((link) => ({ url: link.url, id: link.id }))),
    );
  }
}
