import { Injectable } from '@nestjs/common';
import { CreateUserDto } from './dto/create-user.dto';
import { InjectRepository } from '@nestjs/typeorm';
import { User } from './entities/user.entity';
import { Repository } from 'typeorm';
import {
  UserEmailNotExistsException,
  UserIdNotExistsException,
} from 'src/utils/errors';

@Injectable()
export class UsersService {
  constructor(
    @InjectRepository(User)
    private usersRepository: Repository<User>,
  ) {}

  async getByEmail(email: string) {
    const user = await this.usersRepository.findOneBy({ email });
    if (!user) {
      throw new UserEmailNotExistsException();
    }
    return user;
  }

  async getById(id: number) {
    const user = await this.usersRepository.findOneBy({ id });
    if (!user) {
      throw new UserIdNotExistsException();
    }
    return user;
  }

  async create(userData: CreateUserDto) {
    const user = this.usersRepository.create(userData);
    await this.usersRepository.save(user);
    return user;
  }
}
